<?php

declare(strict_types=1);

namespace Drupal\Tests\multiselect_dropdown\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\Tests\multiselect_dropdown\Traits\MultiselectDropdownTestTrait;

/**
 * Base tests for the multiselect dropdown field widget configuration form.
 *
 * @covers \Drupal\multiselect_dropdown\Plugin\Field\FieldWidget\MultiselectDropdownWidget
 *
 * @group multiselect_dropdown
 */
abstract class MultiselectDropdownWidgetJavascriptTestBase extends WebDriverTestBase {

  use MultiselectDropdownTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'field_ui',
    'multiselect_dropdown_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  private string $path = '/node/add/node';

  /**
   * Dropdowns.
   *
   * @var string[]
   */
  private static array $dropdowns = [
    'field_taxonomy',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->drupalLogin($this->createUser([], NULL, TRUE));
  }

  /**
   * Test that configuration form options are available.
   *
   * @throws \Behat\Mink\Exception\ElementNotFoundException
   * @throws \Behat\Mink\Exception\ExpectationException
   */
  public function testFormOptionsPresent(): void {
    $this->drupalGet('/admin/structure/types/manage/node/form-display');
    $session = $this->assertSession();
    $this->submitForm([], 'field_taxonomy_settings_edit');
    $session->waitForElement('css', '[name="fields[field_taxonomy][settings_edit_form][settings][label_aria]"]');
    $options = [
      'label_aria',
      'label_none',
      'label_all',
      'label_single',
      'label_plural',
      'label_select_all',
      'label_select_none',
    ];
    $session->elementsCount('css', '[name^="fields[field_taxonomy][settings_edit_form][settings]"]', \count($options));
    foreach ($options as $option) {
      $session->elementExists('css', "[name='fields[field_taxonomy][settings_edit_form][settings][$option]']");
    }
  }

}
